==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1DeploymentListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface AppsV1beta1DeploymentListFluent<A extends AppsV1beta1DeploymentListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,AppsV1beta1Deployment item);
    public A setToItems(int index,AppsV1beta1Deployment item);
    public A addToItems(AppsV1beta1Deployment... items);
    public A addAllToItems(Collection<AppsV1beta1Deployment> items);
    public A removeFromItems(AppsV1beta1Deployment... items);
    public A removeAllFromItems(Collection<AppsV1beta1Deployment> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<AppsV1beta1Deployment> getItems();
    public List<AppsV1beta1Deployment> buildItems();
    public AppsV1beta1Deployment buildItem(int index);
    public AppsV1beta1Deployment buildFirstItem();
    public AppsV1beta1Deployment buildLastItem();
    public AppsV1beta1Deployment buildMatchingItem(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentBuilder> predicate);
    public A withItems(List<AppsV1beta1Deployment> items);
    public A withItems(AppsV1beta1Deployment... items);
    public Boolean hasItems();
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> addNewItem();
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> addNewItemLike(AppsV1beta1Deployment item);
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> setNewItemLike(int index,AppsV1beta1Deployment item);
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> editItem(int index);
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> editFirstItem();
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> editLastItem();
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> withNewMetadata();
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> editMetadata();
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> editOrNewMetadata();
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1DeploymentFluent<AppsV1beta1DeploymentListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<AppsV1beta1DeploymentListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1DeploymentListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface AppsV1beta1DeploymentListFluent<A extends AppsV1beta1DeploymentListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,AppsV1beta1Deployment item);
    public A setToItems(int index,AppsV1beta1Deployment item);
    public A addToItems(AppsV1beta1Deployment... items);
    public A addAllToItems(Collection<AppsV1beta1Deployment> items);
    public A removeFromItems(AppsV1beta1Deployment... items);
    public A removeAllFromItems(Collection<AppsV1beta1Deployment> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<AppsV1beta1Deployment> getItems();
    public List<AppsV1beta1Deployment> buildItems();
    public AppsV1beta1Deployment buildItem(int index);
    public AppsV1beta1Deployment buildFirstItem();
    public AppsV1beta1Deployment buildLastItem();
    public AppsV1beta1Deployment buildMatchingItem(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentBuilder> predicate);
    public A withItems(List<AppsV1beta1Deployment> items);
    public A withItems(AppsV1beta1Deployment... items);
    public Boolean hasItems();
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> addNewItem();
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> addNewItemLike(AppsV1beta1Deployment item);
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> setNewItemLike(int index,AppsV1beta1Deployment item);
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> editItem(int index);
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> editFirstItem();
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> editLastItem();
    public AppsV1beta1DeploymentListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<AppsV1beta1DeploymentBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> withNewMetadata();
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> editMetadata();
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> editOrNewMetadata();
    public AppsV1beta1DeploymentListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1DeploymentFluent<AppsV1beta1DeploymentListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<AppsV1beta1DeploymentListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
